# Table of Contents

- [application-rationalization-understand-strategy](<./application-rationalization-understand-strategy.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Step 1: Understand Your Strategy](<./Step-1-Understand-Your-Strategy.md>)
  - [IT Strategy as the Basis for Application Rationalization](<./Step-1-Understand-Your-Strategy/IT-Strategy-as-the-Basis-for-Application-Rationalization.md>)
  - [Example](<./Step-1-Understand-Your-Strategy/Example.md>)
  - [Was this page helpful?](<./Step-1-Understand-Your-Strategy/Was-this-page-helpful.md>)
